﻿Fluke Corporation                                           MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub AT MSO/DSO6xxx Select Channel
INSTRUMENT:            Sub AT MSO/DSO6xxx Wait for Triggered
INSTRUMENT:            Sub AT MSO/DSO6xxx Check Date Code
INSTRUMENT:            Sub AT MSO/DSO6xxx Check Firmware Revision
DATE:                  2011-02-08 09:52:10
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       5
NUMBER OF LINES:       294
=============================================================================
#
#  Procedure Author:
#        GCM, DFM, CAD
#
#  Model(s) Covered:
#        Agilent MSO/DSO6000 Series: MSO/DSO6012A, MSO/DSO6014A, MSO/DSO6032A,
#        MSO/DSO6034A, MSO/DSO6052A, MSO/DSO6054A, MSO/DSO6102A, MSO/DSO6104A
#
#  Compatibility:
#        MET/CAL 7.11 SP1 (7.11j) or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        xso6000_date_code.bmp
#
#  Additional Equipment Required:
#        None
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  JMPL         CHANNEL                      PSUBI("Channel")
  1.002  JMPL         TRIGGERED                    PSUBI("Triggered")
  1.003  JMPL         DATE_CODE                    PSUBI("Date Code")
  1.004  JMPL         FIRMWARE                     PSUBI("Firmware")

  1.005  DISP         Undefined subprocedure!

  1.006  END

  1.007  EVAL   Increment step number


# Sub AT MSO/DSO6xxx Select Channel ==========================================

  2.001  LABEL        CHANNEL

# Select ON/OFF based on whether UUT is 2 or 4 channel.
  2.002  IF           @NumChan == 2

# Specify channel being tested.
  2.003  IF           @Chan == 1
  2.004  IEEE         [S 9]CHAN1:DISP ON;:CHAN2:DISP OFF
  2.005  ELSEIF       @Chan == 2
  2.006  IEEE         [S 9]CHAN1:DISP OFF;:CHAN2:DISP ON
  2.007  ELSE
  2.008  DISP         Sub AT MSO/DSO6xxx Select Channel
  2.008  DISP
  2.008  DISP         [V @UUT_Model] is a 2 channel UUT,
  2.008  DISP         [V @Chan] is an unsupported channel.
  2.009  END
  2.010  ENDIF

  2.011  ELSEIF       @NumChan == 4

# Specify channel being tested.
  2.012  IF           @Chan == 1
  2.013  IEEE         [S 9]CHAN1:DISP ON;:CHAN2:DISP OFF
  2.014  IEEE         [S 9]CHAN3:DISP OFF;:CHAN4:DISP OFF
  2.015  ELSEIF       @Chan == 2
  2.016  IEEE         [S 9]CHAN1:DISP OFF;:CHAN2:DISP ON
  2.017  IEEE         [S 9]CHAN3:DISP OFF;:CHAN4:DISP OFF
  2.018  ELSEIF       @Chan == 3
  2.019  IEEE         [S 9]CHAN1:DISP OFF;:CHAN2:DISP OFF
  2.020  IEEE         [S 9]CHAN3:DISP ON;:CHAN4:DISP OFF
  2.021  ELSEIF       @Chan == 4
  2.022  IEEE         [S 9]CHAN1:DISP OFF;:CHAN2:DISP OFF
  2.023  IEEE         [S 9]CHAN3:DISP OFF;:CHAN4:DISP ON
  2.024  ELSE
  2.025  DISP         Sub AT MSO/DSO6xxx Select Channel
  2.025  DISP
  2.025  DISP         [V @UUT_Model] is a 4 channel UUT,
  2.025  DISP         [V @Chan] is an unsupported channel.
  2.026  END
  2.027  ENDIF

  2.028  ELSE

  2.029  DISP         Sub AT MSO/DSO6xxx Select Channel supports
  2.029  DISP         2 and 4 channel UUTs.
  2.029  DISP
  2.029  DISP         [V @NumChan] is an unsupported number of channels.
  2.030  END

  2.031  ENDIF

  2.032  END

  2.033  EVAL   Increment step number


# Sub AT MSO/DSO6xxx Wait for Triggered ======================================
#
# Description:
#   This subprocedure is used to detect if the sweep is triggered or not.
#
#
# Example Usage:
#
#   7.008  CALL         Sub AT MSO/DSO6xxx Wait for Triggered

  3.001  LABEL        TRIGGERED

# Initialize elapsed time counter, timeout, Trigger state, and Abort state.
  3.002  MATH         ET_Counter = 0; Timeout = 3000
  3.003  MATH         @Trig = 0; @Abort = 0

# Setup conditions which will set the ESB bit in the status byte:
#     Command Error (CME)                 32
#     Execution Error (EXE)               16
#     Device Dependent Error (DDE)         8
#     Query Error (QYE)                    4
#                                         --
#     Event Status Enable Register (ESE)  60
#
  3.004  IEEE         [S 9]*SRE 0;*ESE 60;*CLS

# Serial poll the instrument until the ESB or TRG is set in the status byte.

  3.005  DO
# TRG is bit 0 (1) and ESB is bit 5 (32), decimal 48.
  3.006  IEEE         [S 9][SPL]

  3.007  IF           BIT(5, MEM)

  3.008  DO
  3.009  IEEE         [S 9]SYST:ERR?[I$]
  3.010  MATH         L[1] = MEM2

  3.011  IF           L[1]
  3.012  OPBR         [MEM2]
  3.012  OPBR
  3.012  OPBR         Do you wish to continue?

  3.013  IF           MEM1 < 0
  3.014  MATH         @Abort = 1
  3.015  END
  3.016  ENDIF        ; Continue on error.

  3.017  ENDIF        ; Check for error.

  3.018  IEEE         [S 9]SYST:ERR?[I$]
  3.019  MATH         L[1] = MEM2
  3.020  UNTIL        L[1] == 0

  3.021  ENDIF        ; Check bit 5.

  3.022  WAIT         [D1000]
  3.023  MATH         ET_Counter = ET_Counter + 1
  3.024  MATH         Timeout = Timeout - 1000

  3.025  IF           Timeout <= 0
  3.026  OPBR         Adjust the UUT TRIGGER LEVEL control to achieve
  3.026  OPBR         a stable trigger.
  3.026  OPBR
  3.026  OPBR         Was a stable trigger achieved?

  3.027  IF           MEM1 < 0
  3.028  MATH         @Abort = 1
  3.029  END
  3.030  ENDIF        ; Manual trigger check.

  3.031  ENDIF        ; Timeout

  3.032  UNTIL        BIT(0, MEM)

  3.033  MATH         @Trig = 1

  3.034  END

  3.035  EVAL   Increment Step Number


# Sub AT MSO/DSO6xxx Check Date Code =========================================

  4.001  LABEL        DATE_CODE

# Example usage:
#
#  1.024  CALL         Sub AT MSO/DSO6xxx Check Date Code
#
#    Then:
#
#  1.092  IF           @MfgYear > 8
#  1.093  CALL         Sub AT MSO/DSO60xx (1 yr) Time Scale IEEE /5520+S6
#  1.094  ENDIF
#
# Calculated tolerance is stored in @TimeScaleLimit.
#

  4.002  DO
  4.003  PIC          xso6000_date_code
  4.004  MEM2         Enter the UUT four digit date code:

  4.005  IF           LEN(MEM2) != 4 || NOT(IS_NUM(MEM2))
  4.006  DISP         The date code entered is incorrect.
  4.007  MATH         DateValid = 0

  4.008  ELSE
  4.009  MATH         MEM = MEM2

  4.010  IF           MEM > 9952 || MEM <= 1
  4.011  DISP         The date code entered is incorrect.
  4.012  MATH         DateValid = 0
  4.013  ELSE
  4.014  MATH         DateValid = 1
  4.015  ENDIF

  4.016  ENDIF

  4.017  UNTIL        DateValid

# Parse the UUT manufactured Date Code (0747: 07 = week, 47 = year)..
  4.018  MATH         @MfgYear = SUB(MEM2, 1, 2)
  4.019  MATH         MfgWeek = SUB(MEM2, 3, 2)

# Assumes the Date Code Week range is 01 - 52, and that all units were
# manufactured on Friday to produce the most conservative spec with known
# information.
  4.020  MATH         WksSinceMfg = 52 - MfgWeek

# Parse the current date.
  4.021  MATH         CurrentDate  = DATE("DD/MM/YY")
  4.022  MATH         CurrentDay   = FLD(CurrentDate, 1, "/")
  4.023  MATH         CurrentMonth = FLD(CurrentDate, 2, "/")
  4.024  MATH         CurrentYear  = FLD(CurrentDate, 3, "/")
  4.025  MATH         CurrentWeek  = (CurrentMonth * 4) + (CurrentDay / 7)

# Calculate the number of year since the UUT was manufactured.
  4.026  MATH         DeltaYears  = CurrentYear - @MfgYear
  4.027  MATH         DeltaWeeks  = CurrentWeek + WksSinceMfg

# Subtract one year since we are only interested in the remaining portion of
# the year it was manufactured, and the portion of this year that has passed.
  4.028  MATH         YrsSinceMfg = DeltaYears + (DeltaWeeks / 52) - 1

# Calculate the test scale limit.
  4.029  MATH         @TimeScaleLimit = FMT(15 + 2 * YrsSinceMfg, "%4.2f")

  4.030  END

  4.031  EVAL   Increment Step Number


# Sub AT MSO/DSO6xxx Check Firmware Revision =================================

  5.001  LABEL        FIRMWARE

# Parse firmware returned by *IDN? query.
  5.002  MATH         L[1] = FLD(@FirmwareRev, 1, ".")
  5.003  MATH         L[2] = FLD(@FirmwareRev, 2, ".")
  5.004  MATH         L[3] = FLD(@FirmwareRev, 3, ".")

# Convert firmware revision to a decimal value.
  5.005  MATH         L[4] = L[1] + (L[2] / 100) + (L[3] / 10E+3)

# Check for firmware revision 06.15.0001 or later.
  5.006  IF           (L[4] < 6.1501)

  5.007  MATH         @Abort = 1

  5.008  RSLT         =
  5.009  DISP         {This procedure requires firmware version 06.15.0001}
  5.009  DISP         {or later.}  To update your UUT firmware, visit:
  5.009  DISP
  5.009  DISP         http://www.agilent.com/find/6000

  5.010  ELSE

  5.011  MATH         @Abort = 0

  5.012  ENDIF

  5.013  END
